@@ -28,15 +28,26 @@
 #include <stdlib.h>
 
 #include "gis-assistant-gtk.h"
+#include "gis-assistant-gd.h"
 
-#ifdef HAVE_CLUTTER
-#include <clutter-gtk/clutter-gtk.h>
-#include "gis-assistant-clutter.h"
-#endif
+#define GIS_TYPE_DRIVER_MODE (gis_driver_mode_get_type ())
 
-#ifdef HAVE_CLUTTER
-#include "gis-assistant-clutter.h"
-#endif
+/* Statically include this for now. Maybe later
+ * we'll generate this from glib-mkenums. */
+GType
+gis_driver_mode_get_type (void) {
+  static GType enum_type_id = 0;
+  if (G_UNLIKELY (!enum_type_id))
+    {
+      static const GEnumValue values[] = {
+        { GIS_DRIVER_MODE_NEW_USER, "GIS_DRIVER_MODE_NEW_USER", "new_user" },
+        { GIS_DRIVER_MODE_EXISTING_USER, "GIS_DRIVER_MODE_EXISTING_USER", "existing_user" },
+        { 0, NULL, NULL }
+      };
+      enum_type_id = g_enum_register_static("GisDriverMode", values);
+    }
+  return enum_type_id;
+}
 
 G_DEFINE_TYPE(GisDriver, gis_driver, GTK_TYPE_APPLICATION)
 
@@ -44,17 +55,28 @@ G_DEFINE_TYPE(GisDriver, gis_driver, GTK_TYPE_APPLICATION)
 
 enum {
   REBUILD_PAGES,
+  LOCALE_CHANGED,
   LAST_SIGNAL,
 };
 
 static guint signals[LAST_SIGNAL];
 
+enum {
+  PROP_0,
+  PROP_MODE,
+  PROP_LAST,
+};
+
+static GParamSpec *obj_props[PROP_LAST];
+
 struct _GisDriverPrivate {
   GtkWindow *main_window;
   GisAssistant *assistant;
 
   ActUser *user_account;
   const gchar *user_password;
+
+  GisDriverMode mode;
 };
 
 static void
@@ -66,20 +88,20 @@ title_changed_cb (GisAssistant *assistant,
   gtk_window_set_title (priv->main_window, gis_assistant_get_title (assistant));
 }
 
-static void
-recenter_window (GdkScreen *screen, GisDriver *driver)
-{
-  GisDriverPrivate *priv = driver->priv;
-  gtk_window_set_position (priv->main_window, GTK_WIN_POS_CENTER_ALWAYS);
-}
-
 static void
 prepare_main_window (GisDriver *driver)
 {
   GisDriverPrivate *priv = driver->priv;
+  GdkGeometry size_hints;
 
-  g_signal_connect (gtk_widget_get_screen (GTK_WIDGET (priv->main_window)),
-                    "monitors-changed", G_CALLBACK (recenter_window), driver);
+  size_hints.min_width = 680;
+  size_hints.min_height = 440;
+  size_hints.win_gravity = GDK_GRAVITY_CENTER;
+
+  gtk_window_set_geometry_hints (priv->main_window,
+                                 GTK_WIDGET (priv->main_window),
+                                 &size_hints,
+                                 GDK_HINT_MIN_SIZE | GDK_HINT_WIN_GRAVITY);
 
   g_signal_connect (priv->assistant, "notify::title",
                     G_CALLBACK (title_changed_cb), driver);
@@ -127,28 +149,75 @@ gis_driver_add_page (GisDriver *driver,
   gis_assistant_add_page (priv->assistant, page);
 }
 
-void
-gis_driver_locale_changed (GisDriver *driver)
+static void
+gis_driver_real_locale_changed (GisDriver *driver)
 {
   GisDriverPrivate *priv = driver->priv;
   g_idle_add ((GSourceFunc) rebuild_pages, driver);
   gis_assistant_locale_changed (priv->assistant);
 }
 
+void
+gis_driver_locale_changed (GisDriver *driver)
+{
+  g_signal_emit (G_OBJECT (driver), signals[LOCALE_CHANGED], 0);
+}
+
+GisDriverMode
+gis_driver_get_mode (GisDriver *driver)
+{
+  GisDriverPrivate *priv = driver->priv;
+  return priv->mode;
+}
+
 static GType
 get_assistant_type (void)
 {
-#ifdef HAVE_CLUTTER
   gboolean enable_animations;
   g_object_get (gtk_settings_get_default (),
                 "gtk-enable-animations", &enable_animations,
                 NULL);
 
-  if (enable_animations && g_getenv ("GIS_DISABLE_CLUTTER") == NULL)
-    return GIS_TYPE_ASSISTANT_CLUTTER;
-#endif /* HAVE_CLUTTER */
+  if (enable_animations && g_getenv ("GIS_DISABLE_GD") == NULL)
+    return GIS_TYPE_ASSISTANT_GD;
+  else
+    return GIS_TYPE_ASSISTANT_GTK;
+}
 
-  return GIS_TYPE_ASSISTANT_GTK;
+static void
+gis_driver_get_property (GObject      *object,
+                         guint         prop_id,
+                         GValue       *value,
+                         GParamSpec   *pspec)
+{
+  GisDriver *driver = GIS_DRIVER (object);
+  switch (prop_id)
+    {
+    case PROP_MODE:
+      g_value_set_enum (value, driver->priv->mode);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+gis_driver_set_property (GObject      *object,
+                         guint         prop_id,
+                         const GValue *value,
+                         GParamSpec   *pspec)
+{
+  GisDriver *driver = GIS_DRIVER (object);
+  switch (prop_id)
+    {
+    case PROP_MODE:
+      driver->priv->mode = g_value_get_enum (value);
+      break;
+   default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
 }
 
 static void
@@ -199,11 +268,15 @@ static void
 gis_driver_class_init (GisDriverClass *klass)
 {
   GApplicationClass *application_class = G_APPLICATION_CLASS (klass);
+  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GisDriverPrivate));
 
+  gobject_class->get_property = gis_driver_get_property;
+  gobject_class->set_property = gis_driver_set_property;
   application_class->startup = gis_driver_startup;
   application_class->activate = gis_driver_activate;
+  klass->locale_changed = gis_driver_real_locale_changed;
 
   signals[REBUILD_PAGES] =
     g_signal_new ("rebuild-pages",
@@ -212,12 +285,29 @@ gis_driver_class_init (GisDriverClass *klass)
                   G_STRUCT_OFFSET (GisDriverClass, rebuild_pages),
                   NULL, NULL, NULL,
                   G_TYPE_NONE, 0);
+
+  signals[LOCALE_CHANGED] =
+    g_signal_new ("locale-changed",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_FIRST,
+                  G_STRUCT_OFFSET (GisDriverClass, locale_changed),
+                  NULL, NULL, NULL,
+                  G_TYPE_NONE, 0);
+
+  obj_props[PROP_MODE] =
+    g_param_spec_enum ("mode", "", "",
+                       GIS_TYPE_DRIVER_MODE,
+                       GIS_DRIVER_MODE_EXISTING_USER,
+                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
+  g_object_class_install_properties (gobject_class, PROP_LAST, obj_props);
 }
 
 GisDriver *
-gis_driver_new (void)
+gis_driver_new (GisDriverMode mode)
 {
   return g_object_new (GIS_TYPE_DRIVER,
                        "application-id", "org.gnome.InitialSetup",
+                       "mode", mode,
                        NULL);
 }
