@@ -27,6 +27,7 @@
 
 #include "config.h"
 #include "gis-goa-page.h"
+#include "goa-resources.h"
 
 #define GOA_API_IS_SUBJECT_TO_CHANGE
 #include <goa/goa.h>
@@ -351,7 +352,6 @@ gis_goa_page_constructed (GObject *object)
   g_signal_connect (priv->goa_client, "account-removed",
                     G_CALLBACK (goa_account_removed), page);
 
-  gis_page_set_title (GIS_PAGE (page), _("Online Accounts"));
   gis_page_set_complete (GIS_PAGE (page), TRUE);
 
   gtk_widget_show (GTK_WIDGET (page));
@@ -368,6 +368,12 @@ gis_goa_page_dispose (GObject *object)
   G_OBJECT_CLASS (gis_goa_page_parent_class)->dispose (object);
 }
 
+static void
+gis_goa_page_locale_changed (GisPage *page)
+{
+  gis_page_set_title (GIS_PAGE (page), _("Online Accounts"));
+}
+
 static void
 gis_goa_page_class_init (GisGoaPageClass *klass)
 {
@@ -375,6 +381,7 @@ gis_goa_page_class_init (GisGoaPageClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   page_class->page_id = PAGE_ID;
+  page_class->locale_changed = gis_goa_page_locale_changed;
   object_class->constructed = gis_goa_page_constructed;
   object_class->dispose = gis_goa_page_dispose;
   
@@ -384,6 +391,7 @@ gis_goa_page_class_init (GisGoaPageClass *klass)
 static void
 gis_goa_page_init (GisGoaPage *page)
 {
+  g_resources_register (goa_get_resource ());
   page->priv = GET_PRIVATE (page);
 }
 
