@@ -194,17 +194,22 @@ log_user_in (GisSummaryPage *page)
   }
 }
 
-#define INITIAL_SETUP_TRIGGER_FILE LOCALSTATEDIR "/lib/gdm/run-initial-setup"
-
 static void
-remove_trigger_file (GisSummaryPage *page)
+add_setup_done_file (void)
 {
+  gchar *gis_done_path;
   GError *error = NULL;
-  if (!g_spawn_command_line_sync ("/usr/bin/pkexec /usr/bin/rm " INITIAL_SETUP_TRIGGER_FILE, NULL, NULL, NULL, &error))
-    {
-      g_warning ("Failed to remove '" INITIAL_SETUP_TRIGGER_FILE "': %s", error->message);
-      g_error_free (error);
+
+  gis_done_path = g_build_filename (g_get_user_config_dir (),
+                                    "gnome-initial-setup-done",
+                                    NULL);
+
+  if (!g_file_set_contents (gis_done_path, "yes", -1, &error)) {
+      g_warning ("Unable to create %s: %s", gis_done_path, error->message);
+      g_clear_error (&error);
   }
+
+  g_free (gis_done_path);
 }
 
 static void
@@ -221,9 +226,9 @@ done_cb (GtkButton *button, GisSummaryPage *page)
     {
     case GIS_DRIVER_MODE_NEW_USER:
       log_user_in (page);
-      remove_trigger_file (page);
       break;
     case GIS_DRIVER_MODE_EXISTING_USER:
+      add_setup_done_file ();
       g_application_quit (G_APPLICATION (GIS_PAGE (page)->driver));
     default:
       break;
